Crate mio_signals

Crate for handling signals with Mio.

See the Signals documentation.

Supported platforms

Currently supported platforms:

  • Android
  • DragonFly BSD
  • FreeBSD
  • Linux
  • NetBSD
  • OpenBSD
  • iOS
  • macOS

The most notable exception in the list is Windows. If you want to contribute a port to Windows please see issue #4.

Structs

Enums

Functions